.. currentmodule:: pdcast

.. _float_types:

Float
=====

Generic
-------

.. _float_type:

.. autoclass:: FloatType

.. _float16_type:

.. autoclass:: Float16Type

.. _float32_type:

.. autoclass:: Float32Type

.. _float64_type:

.. autoclass:: Float64Type

.. _float80_type:

.. autoclass:: Float80Type

Numpy
-----

.. _numpy_float_type:

.. autoclass:: NumpyFloatType

.. _numpy_float16_type:

.. autoclass:: NumpyFloat16Type

.. _numpy_float32_type:

.. autoclass:: NumpyFloat32Type

.. _numpy_float64_type:

.. autoclass:: NumpyFloat64Type

.. _numpy_float80_type:

.. autoclass:: NumpyFloat80Type

Python
------

.. _python_float_type:

.. autoclass:: PythonFloatType
